SWITCH

2

PORTS

Connected

SYSTEM INFO

Firmware Version

1.0.4.4

Check for firmware on

NETGEAR.COM

Switch Name

MAC Address

E0:46:EE:35:6B:CB

Serial Number

6LA6375EA0249

Model Number

GS316EPP

Language
CANCEL APPLY
Port LEDs
OFF (Stealth Mode)
ON (LEDs Active)
CANCEL APPLY
IP Address

DHCP

Assign the IP address automatically.

IP Address
Subnet Mask
Gateway Address
Primary DNS Server Address
Secondary DNS Server Address
CANCEL APPLY
LAG LAG 1: (Ports: None)
LAG 2: (Ports: None)
LAG 3: (Ports: None)
LAG 4: (Ports: None)
LAG 5: (Ports: None)
LAG 6: (Ports: None)
LAG 7: (Ports: None)
LAG 8: (Ports: None)
PRESET MODES

Optimize performance with preset configurations.

SYSTEM TIME

Local/SNTP

Local SNTP
[SNTP Server Configuration]
Date
Time
Time Zone
System Uptime 51 hrs, 56 mins, 4 secs
CANCEL APPLY
PORT STATUS

#### 1 - CONNECTED

Speed

Auto

Linked Speed

100M Full

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 2 - CONNECTED

Speed

Auto

Linked Speed

1000M Full

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 3 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 4 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 5 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 6 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 7 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 8 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 9 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 10 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 11 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 12 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 13 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 14 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 15 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY

#### 16 - AVAILABLE

Speed

Auto

Linked Speed

No Speed

Ingress Port Limit

No Limit

Egress Port Limit

No Limit

Flow Control

OFF

EDIT
Port Name (1-16 Characters)
Speed
Ingress Port Limit
Egress Port Limit

Flow Control

Turn on to regulate and prevent traffic on this port from affecting performance of other ports.

CANCEL APPLY